ValueStreamExt

Trait ValueStreamExt 

pub trait ValueStreamExt {
    // Required method
    fn buffered(&self) -> Vec<Value>;
}
Extension trait for ValueStream providing convenient testing methods

Required Methods

fn buffered(&self) -> Vec<Value>

Returns buffered values, asserting that the stream is fully buffered

This method will panic if the stream is not fully buffered (i.e., if there are still pending values in the stream that haven’t been loaded into the buffer). Use this in tests when you want to access buffered values synchronously.

Implementations on Foreign Types

Source

impl ValueStreamExt for ValueStream

Blanket implementation of ValueStreamExt for ValueStream

Source

fn buffered(&self) -> Vec<Value>

Implementors