delete_by_partition_key

Function delete_by_partition_key 

pub async fn delete_by_partition_key(test: &mut Test)
Test delete on a model with a partitioned composite primary key using the partition-key-only filter.

Todo::filter_by_user_id(user_id).delete() must delete all matching records, not silently skip the deletion by issuing only a read-only QueryPk.