pub async fn basic_embedded_enum(test: &mut Test)
Tests that embedded enums are registered in the app schema but don’t create their own database tables (they’re inlined into parent models as a single column).